<img alt="CBR Logo" width="300px" src="https://static.dev.aws.cyber-boardroom.com/cbr-static/latest/assets/cbr/cbr-logo-beta.png" style="display: block; margin: 0 auto;">

**Welcome to The Cyber Boardroom**, the one-stop shop that boards of directors rely on for their cyber readiness.

The Cyber Boardroom’s mission is to help you understand your organisation’s cyber security agenda, 
as well as fulfil your duties as a board member.

To help you with any questions you might have on cyber security and the risks your organisation faces, 
we have created an engaging AI advisor named [Athena](athena).

To ensure [Athena](athena) delivers a personalised experience, go to your profile section, scroll down, 
and add as many prompts as you want.

In addition, we are building a customised library of short videos and valuable content aimed at 
enhancing your knowledge of cyber security, which will help you optimise your engagement with [Athena](athena).